==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/METERINTERVAL_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour METERINTERVAL_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="METERINTERVAL_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="INTERVAL" type="{http://www.openapplications.org/oagis_segments}QUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *         &lt;element name="READINGDUE" type="{http://www.openapplications.org/oagis_segments}QUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NESTINGBUFFER" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "METERINTERVAL_Type", propOrder = {
    "interval",
    "uomid",
    "readingdue",
    "nestingbuffer"
})
public class METERINTERVAL_Type {

    @XmlElement(name = "INTERVAL", required = true)
    protected QUANTITY interval;
    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;
    @XmlElement(name = "READINGDUE")
    protected QUANTITY readingdue;
    @XmlElement(name = "NESTINGBUFFER")
    protected NESTINGBUFFER_Type nestingbuffer;

    /**
     * Obtient la valeur de la propriété interval.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getINTERVAL() {
        return interval;
    }

    /**
     * Définit la valeur de la propriété interval.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setINTERVAL(QUANTITY value) {
        this.interval = value;
    }

    /**
     * Obtient la valeur de la propriété uomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Définit la valeur de la propriété uomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Obtient la valeur de la propriété readingdue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREADINGDUE() {
        return readingdue;
    }

    /**
     * Définit la valeur de la propriété readingdue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREADINGDUE(QUANTITY value) {
        this.readingdue = value;
    }

    /**
     * Obtient la valeur de la propriété nestingbuffer.
     * 
     * @return
     *     possible object is
     *     {@link NESTINGBUFFER_Type }
     *     
     */
    public NESTINGBUFFER_Type getNESTINGBUFFER() {
        return nestingbuffer;
    }

    /**
     * Définit la valeur de la propriété nestingbuffer.
     * 
     * @param value
     *     allowed object is
     *     {@link NESTINGBUFFER_Type }
     *     
     */
    public void setNESTINGBUFFER(NESTINGBUFFER_Type value) {
        this.nestingbuffer = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/METERINTERVAL_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for METERINTERVAL_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="METERINTERVAL_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="INTERVAL" type="{http://www.openapplications.org/oagis_segments}QUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *         &lt;element name="READINGDUE" type="{http://www.openapplications.org/oagis_segments}QUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NESTINGBUFFER" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "METERINTERVAL_Type", propOrder = {
    "interval",
    "uomid",
    "readingdue",
    "nestingbuffer"
})
public class METERINTERVAL_Type {

    @XmlElement(name = "INTERVAL", required = true)
    protected QUANTITY interval;
    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;
    @XmlElement(name = "READINGDUE")
    protected QUANTITY readingdue;
    @XmlElement(name = "NESTINGBUFFER")
    protected NESTINGBUFFER_Type nestingbuffer;

    /**
     * Gets the value of the interval property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getINTERVAL() {
        return interval;
    }

    /**
     * Sets the value of the interval property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setINTERVAL(QUANTITY value) {
        this.interval = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the readingdue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREADINGDUE() {
        return readingdue;
    }

    /**
     * Sets the value of the readingdue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREADINGDUE(QUANTITY value) {
        this.readingdue = value;
    }

    /**
     * Gets the value of the nestingbuffer property.
     * 
     * @return
     *     possible object is
     *     {@link NESTINGBUFFER_Type }
     *     
     */
    public NESTINGBUFFER_Type getNESTINGBUFFER() {
        return nestingbuffer;
    }

    /**
     * Sets the value of the nestingbuffer property.
     * 
     * @param value
     *     allowed object is
     *     {@link NESTINGBUFFER_Type }
     *     
     */
    public void setNESTINGBUFFER(NESTINGBUFFER_Type value) {
        this.nestingbuffer = value;
    }

}
